import click
import nltk

from dotenv import load_dotenv
from commands import scrape, split

# Downloading punkt only when it's not present
nltk.download('punkt', quiet=True)

load_dotenv()


# CLI Main Group
@click.group()
def cli():
    """Wayble is the official CLI for Wayble AI"""
    pass


cli.add_command(scrape.scrape)
cli.add_command(split.split)

if __name__ == '__main__':
    cli()



import json
import functools


def jsonio(func):
    """
    A decorator that abstracts away the reading and writing of JSON data.
    """
    @functools.wraps(func)
    def wrapper(input_file, output_file, *args, **kwargs):
        with open(input_file, 'r') as f:
            data = json.load(f)

        result = func(data, *args, **kwargs)

        with open(output_file, 'w') as f:
            json.dump(result, f)

    return wrapper



import click

from typing import TypedDict
from langchain.document_loaders import TextLoader
from langchain.text_splitter import RecursiveCharacterTextSplitter
from lib.jsonio import jsonio


class InputParams(TypedDict):
    input_file: str
    chunk_size: int
    overlap_size: int


@click.command()
@click.argument('input_file', type=click.Path(exists=True, readable=True))
@click.argument('output_file', type=click.Path(writable=True))
@jsonio
def split(params: InputParams) -> list:
    """
    Splits text from text files into chunks and writes the result to the output file in JSON format.

    [INPUT_FILE] is the path to a JSON file with the input params.\n
    👉 { input_file: str, chunk_size: int(256), overlap_size: int(128) }

    [OUTPUT_FILE] is the path to the file to which the chunks will be saved.
    """
    loader = TextLoader(params['input_file'])
    documents = loader.load()

    text_splitter = RecursiveCharacterTextSplitter(
        chunk_overlap=params.get('overlap_size', 128),
        chunk_size=params.get('chunk_size', 512)
    )

    # Split the documents into chunks
    docs = text_splitter.split_documents(documents)

    # Extract page content from each document
    return [doc.page_content for doc in docs]



import click
import requests

from lib.jsonio import jsonio
from typing import TypedDict
from bs4 import BeautifulSoup


class InputParams(TypedDict):
    url: str


@click.command()
@click.argument('input_file', type=click.Path(exists=True, readable=True))
@click.argument('output_file', type=click.Path(writable=True))
@jsonio
def scrape(params: InputParams) -> str:
    """
    Scrapes text content from the specified URL and saves it to the output file.

    [INPUT_FILE] is the path to a JSON file with the input params.\n
    👉 { url: str }

    [OUTPUT_FILE] is the path to the file to which the scraped content will be saved.
    """
    try:
        response = requests.get(params.get('url'))
        response.raise_for_status()  # Ensure we got a successful response

        # Parse the content using BeautifulSoup
        soup = BeautifulSoup(response.content, 'html.parser')

        # Extract and join text from the parsed HTML content
        text = " ".join(soup.stripped_strings)

        return {'content': text}

    except requests.RequestException as e:
        raise click.ClickException(f"Error extracting content from {params.get('url')}: {e}")
